==> dde-control-center_5.5.88.orig.tar.xz: dde-control-center-5.5.88/translations/recovery_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi geri alıyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>Geri alma başarısız.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2&apos;de yedeklenmiş %1&apos;e geri dönmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>İptal et ve Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.197.orig.tar.xz: dde-control-center-5.5.197/translations/recovery_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi geri alıyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation>Geri alma başarısız.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2&apos;de yedeklenmiş %1&apos;e geri dönmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation>İptal et ve Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>
